==> nextcloud-23.0.8.tgz: nextcloud/apps/password_policy/l10n/gl.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Caducou o contrasinal, use o método de contrasinal esquecido para restabelecelo",
    "Password must not have been used recently before." : "O contrasinal non debe ter sido empregado recentemente.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "O contrasinal está entre o 1.000.000 máis común. Escolla un diferente.",
    "Password is present in compromised password list. Please choose a different password." : "O contrasinal atopase nunha lista de contrasinais comprometidos. Escolla un contrasinal diferente.",
    "Password needs to be at least %s characters long." : "O contrasinal precisa ser polo menos de %s caracteres de lonxitude.",
    "Password needs to contain at least one numeric character." : "O contrasinal precisa conter polo menos un caracter numérico.",
    "Password needs to contain at least one special character." : "O contrasinal precisa conter polo menos un caracter especial.",
    "Password needs to contain at least one lower and one upper case character." : "O contrasinal precisa conter polo menos un caracter en minúsculas e un en maiúsculas.",
    "Password policy" : "Directiva de contrasinais",
    "Allows admins to configure a password policy" : "Permítelle aos administradores  configurar unha directiva de contrasinais",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Permítelle aos administradores definir certas precondicións para os contrasinais, p. ex., obrigar a unha lonxitude mínima",
    "Saved" : "Gardado",
    "Minimum password length" : "Lonxitude mínima do contrasinal",
    "User password history" : "Historial de contrasinais do usuario",
    "Number of days until user password expires" : "Número de días ata que caduque o contrasinal do usuario",
    "Number of login attempts before the user account is blocked (0 for no limit)" : "Número de intentos de acceso antes de que se bloquee a conta do usuario. (0 para sen límite)",
    "Forbid common passwords" : "Prohibir contrasinais comúns",
    "Enforce upper and lower case characters" : "Forzar caracteres en maiúsculas e minúsculas",
    "Enforce numeric characters" : "Forzar caracteres numéricos",
    "Enforce special characters" : "Forzar caracteres especiais",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Comprobar o contrasinal contra a lista de contrasinais comprometidos de haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Esta comprobación crea un «hash» dos contrasinais e envía os 5 primeiros caracteres deste «hash» á API de haveibeenpwned.com para recuperar unha lista de todos os «hash» que comezan desa forma. Após comprobase na instancia de Nextcloud se o «hash» do contrasinal está no conxunto de resultados.",
    "Unknown error" : "Erro descoñecido",
    "Minimal length has to be a non negative number" : "A lonxitude mínima ten que ser un número non negativo",
    "History size has to be a non negative number" : "O tamaño do historial ten que ser un número non negativo",
    "Expiration days have to be a non negative number" : "Os días de caducidade deben ser un número non negativo",
    "Maximum login attempts have to be a non negative number" : "O máximo de intentos de inicio de sesión debe ser un número non negativo"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-25.0.6.tgz: nextcloud/apps/password_policy/l10n/gl.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Caducou o contrasinal, use o método de contrasinal esquecido para restabelecelo",
    "Password must not have been used recently before." : "O contrasinal non debe ter sido empregado recentemente.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "O contrasinal está entre o 1.000.000 máis común. Escolla un diferente.",
    "Password is present in compromised password list. Please choose a different password." : "O contrasinal atopase nunha lista de contrasinais comprometidos. Escolla un contrasinal diferente.",
    "Password needs to be at least %s characters long." : "O contrasinal precisa ser polo menos de %s caracteres de lonxitude.",
    "Password needs to contain at least one numeric character." : "O contrasinal precisa conter polo menos un caracter numérico.",
    "Password needs to contain at least one special character." : "O contrasinal precisa conter polo menos un caracter especial.",
    "Password needs to contain at least one lower and one upper case character." : "O contrasinal precisa conter polo menos un caracter en minúsculas e un en maiúsculas.",
    "Password policy" : "Directiva de contrasinais",
    "Allows admins to configure a password policy" : "Permítelle aos administradores  configurar unha directiva de contrasinais",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Permítelle aos administradores definir certas precondicións para os contrasinais, p. ex., obrigar a unha lonxitude mínima",
    "Minimum password length" : "Lonxitude mínima do contrasinal",
    "User password history" : "Historial de contrasinais do usuario",
    "Number of days until user password expires" : "Número de días ata que caduque o contrasinal do usuario",
    "Number of login attempts before the user account is blocked (0 for no limit)" : "Número de intentos de acceso antes de que se bloquee a conta do usuario. (0 para sen límite)",
    "Forbid common passwords" : "Prohibir contrasinais comúns",
    "Enforce upper and lower case characters" : "Forzar caracteres en maiúsculas e minúsculas",
    "Enforce numeric characters" : "Forzar caracteres numéricos",
    "Enforce special characters" : "Forzar caracteres especiais",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Comprobar o contrasinal contra a lista de contrasinais comprometidos de haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Esta comprobación crea un «hash» dos contrasinais e envía os 5 primeiros caracteres deste «hash» á API de haveibeenpwned.com para recuperar unha lista de todos os «hash» que comezan desa forma. Após comprobase na instancia de Nextcloud se o «hash» do contrasinal está no conxunto de resultados.",
    "Unknown error" : "Erro descoñecido",
    "Minimal length has to be a non negative number" : "A lonxitude mínima ten que ser un número non negativo",
    "History size has to be a non negative number" : "O tamaño do historial ten que ser un número non negativo",
    "Expiration days have to be a non negative number" : "Os días de caducidade deben ser un número non negativo",
    "Maximum login attempts have to be a non negative number" : "O máximo de intentos de inicio de sesión debe ser un número non negativo",
    "Settings saved" : "Axustes gardados",
    "Error while saving settings" : "Produciuse un erro ao gardar a configuración",
    "Saved" : "Gardado",
    "Error while saving" : "Produciuse un erro ao gardar"
},
"nplurals=2; plural=(n != 1);");
